@@ -3,7 +3,7 @@
  *  project   : xcfa
  *  with      : Gtk-2
  *
- *  copyright : (C) 2003 - 2010 by Claude Bulin
+ *  copyright : (C) 2003 - 2011 by Claude Bulin
  *
  *  xcfa - GTK+ implementation of the GNU shell command
  *  GNU General Public License
@@ -128,12 +128,32 @@ gboolean AlsaAudio_write(int size)
 		* that ALSA recovers. If not, we have a problem, so spit out an 
 		* error message to let the user know something's wrong.
 		*/
+// TODO ESTRPIPE
+// Mon, 06 Dec 2010 23:59:33 +0100
+// 
+// ESTRPIPE n'est pas definit sous KFreeBSD :/
+// asm-generic/errno.h:59:#define    ESTRPIPE    86    /* Streams pipe error */
+// MODIF POUR COMPIL CORRECTE DANS: KFreeBSD suite a un mail de Christian Marillat
+// 
+// kfreebsd-7-7.0
+// src/sys/i386/ibcs2/ibcs2_errno.h:145:#define IBCS2_ESTRPIPE		92
+// src/sys/compat/svr4/svr4_errno.h:116:#define	SVR4_ESTRPIPE		92
+// 
+// Christian Marillat a écrit :
+// Il ne vaut pas mieux utiliser BSM_ERRNO_ESTRPIPE à la place de 92 ?
+// Pour Kfreebsd c'est '__FreeBSD_kernel__'
+// Christian
+// 
+#ifdef __FreeBSD_kernel__
+		#include <bsm/audit_errno.h>
+		if( err == -BSM_ERRNO_ESTRPIPE) {
+#else
 		if( err == -ESTRPIPE) {
+#endif
 			while( (err = snd_pcm_resume (VarAlsa.playback_handle)) == -EAGAIN) {
 				sleep( 1);
 			}
 		}
-
 		err = snd_pcm_prepare (VarAlsa.playback_handle);
 
 		if( err != 0) {
