@@ -3,7 +3,7 @@
  * project   : xcfa
  * with      : Gtk-2
  *
- * copyright : (C) 2003 - 2010 by Claude Bulin
+ * copyright : (C) 2003 - 2011 by Claude Bulin
  *
  * xcfa - GTK+ implementation of the GNU shell command
  * GNU General Public License
@@ -146,7 +146,9 @@ VAR_CONFIG Config = {
 	NULL,		// StringParamNameLecteurAudio
 	NULL,		// StringBoolFieldsIsVisible	FIELDS DVD,CD,FILES : FALSE or HIDE = 0, TRUE or SHOW = 1
 	NULL,		// StringPosFieldsName		POS NAME OF DVD,CD,FILES: 0 = LEFT, 1 = CENTER, 2 = RIGHT
-	0		// NumSelectComboBoxCd
+	0,		// NumSelectComboBoxCd
+	NULL,		// entry_cddp_server
+	NULL		// entry_cddp_port
 };
 
 
@@ -167,7 +169,9 @@ void config_print_data (gchar *p_str)
 // 
 gchar *config_get_pathname (void)
 {
-	return ((gchar *)g_strdup_printf ("%s/%s", getenv ("HOME"), ".config/xcfa_new/xcfa.conf"));
+	// @Tetsumaki : http://forum.ubuntu-fr.org/viewtopic.php?pid=3890967#p3890967
+	// return ((gchar *)g_strdup_printf ("%s/%s", getenv ("HOME"), ".config/xcfa_new/xcfa.conf"));
+	return ((gchar *)g_strdup_printf ("%s/%s", getenv ("HOME"), ".config/xcfa/xcfa.conf"));
 }
 // RETOURNE UNE DEFINITION DU FICHIER DE CONFIGURATION
 // 
@@ -367,7 +371,7 @@ void config_read (void)
 		if (FALSE == config_read_value_atoi (buf, "IND_COMBO_DEST_FILE_WAV",		&Config.TabIndiceComboDestFile[1],	0,	2))
 		if (FALSE == config_read_value_atoi (buf, "IND_COMBO_DEST_FILE_MP3OGG",		&Config.TabIndiceComboDestFile[2],	0,	2))
 		if (FALSE == config_read_value_atoi (buf, "IND_COMBO_DEST_FILE_TAGS",		&Config.TabIndiceComboDestFile[3],	0,	2))
-		if (FALSE == config_read_value_atoi (buf, "SERVER_FREE_CDDB",			&Config.ServeurCddb,			0,	1))
+		if (FALSE == config_read_value_atoi (buf, "SERVER_FREE_CDDB",			&Config.ServeurCddb,			0,	2))
 		if (FALSE == config_read_value_atoi (buf, "NUM_SELECT_COMBOBOX_CD",		&Config.NumSelectComboBoxCd,		0,	10))
 		
 		// READ BOOL
@@ -421,7 +425,11 @@ void config_read (void)
 		if (FALSE == config_read_value_str (buf, "STRING_NAME_LECTEUR_AUDIO",		&Config.StringNameLecteurAudio))
 		if (FALSE == config_read_value_str (buf, "STRING_PARAM_NAME_LECTEUR_AUDIO",	&Config.StringParamNameLecteurAudio))
 		if (FALSE == config_read_value_str (buf, "STRING_BOOL_FIELD_IS_VISIBLE",	&Config.StringBoolFieldsIsVisible))
-		if (FALSE == config_read_value_str (buf, "STRING_POS_FIELD_IS_NAME",		&Config.StringPosFieldsName));
+		if (FALSE == config_read_value_str (buf, "STRING_POS_FIELD_IS_NAME",		&Config.StringPosFieldsName))
+		
+		if (FALSE == config_read_value_str (buf, "STRING_ENTRY_CDDP_SERVER",		&Config.entry_cddp_server))
+		if (FALSE == config_read_value_str (buf, "STRING_ENTRY_CDDP_PORT",		&Config.entry_cddp_port));
+		
 		buf [ 0 ] = '\0';
 	}
 	fclose (fp);
@@ -556,6 +564,8 @@ void config_save (void)
 		fprintf (fp, "STRING_EXPANDER_WAVPACK             = %s\n", Config.StringExpanderWavpack ? Config.StringExpanderWavpack : "");
 		
 		fprintf (fp, "SERVER_FREE_CDDB                    = %d\n", Config.ServeurCddb);
+		fprintf (fp, "STRING_ENTRY_CDDP_SERVER            = %s\n", Config.entry_cddp_server != NULL ? Config.entry_cddp_server : "freedb.freedb.org");
+		fprintf (fp, "STRING_ENTRY_CDDP_PORT              = %s\n", Config.entry_cddp_port != NULL ? Config.entry_cddp_port : "8880");
 		
 		fprintf (fp, "STRING_NAME_FILE_M3U_XSPF           = %s\n", Config.StringNameFile_m3u_xspf ? Config.StringNameFile_m3u_xspf : "");
 		fprintf (fp, "TEMPLATE_TITLE_CDAUDIO              = ");
@@ -638,5 +648,7 @@ void config_remove (void)
 	g_free (Config.StringParamNameLecteurAudio);	Config.StringParamNameLecteurAudio = NULL;
 	g_free (Config.StringBoolFieldsIsVisible);	Config.StringBoolFieldsIsVisible = NULL;
 	g_free (Config.StringPosFieldsName);		Config.StringPosFieldsName = NULL;
+	g_free (Config.entry_cddp_server);		Config.entry_cddp_server = NULL;
+	g_free (Config.entry_cddp_port);		Config.entry_cddp_port = NULL;
 }
 
