@@ -3,7 +3,7 @@
  * project   : xcfa
  * with      : Gtk-2
  *
- * copyright : (C) 2003 - 2010 by Claude Bulin
+ * copyright : (C) 2003 - 2011 by Claude Bulin
  *
  * xcfa - GTK+ implementation of the GNU shell command
  * GNU General Public License
@@ -145,6 +145,9 @@ typedef struct {
 	
 	gint		 NumSelectComboBoxCd;		// 
 	
+	gchar		*entry_cddp_server;		// 
+	gchar		*entry_cddp_port;		// 
+	
 } VAR_CONFIG;
 
 extern VAR_CONFIG Config;
