@@ -3,7 +3,7 @@
  * project   : xcfa
  * with      : Gtk-2
  *
- * copyright : (C) 2003 - 2010 by Claude Bulin
+ * copyright : (C) 2003 - 2011 by Claude Bulin
  *
  * xcfa - GTK+ implementation of the GNU shell command
  * GNU General Public License
@@ -63,14 +63,17 @@
 #include "get_info.h"
 #include "tags.h"
 #include "win_scan.h"
+#include "prg_init.h"
+#include "win_info.h"
 #include "file.h"
 
 
 
 
 typedef struct {
-	gchar	*Name;
-	TYPE_FILESELECTION	TypeFileIs;
+	gchar		*Name;
+	// TYPE_FILESELECTION	TypeFileIs;
+	TYPE_FILE_IS	TypeFileIs;
 } VAR_LIST_FILES;
 
 typedef struct {
@@ -92,6 +95,7 @@ typedef struct {
 	gboolean		BoolInThread;
 	gboolean		BoolSetPercent;
 	guint			HandlerTimeoutDo;
+	gboolean		BoolNoFindCheckMp3;
 	
 } VAR_ANALYZE;
 
@@ -279,8 +283,9 @@ void fileanalyze_recherche_recursive (gchar *Directory)
 	closedir (dp);
 }
 // 
+// RETOURNE UN TYPE [ TYPE_FILE_IS ] OU -1
 // 
-TYPE_FILESELECTION fileanalyze_is_valid (gchar *PathName, TYPE_FILESELECTION p_TypeFileselection)
+TYPE_FILE_IS fileanalyze_is_valid (gchar *PathName, TYPE_FILESELECTION p_TypeFileselection)
 {
 	/*gchar	*TabFileAll[]    = {".WAV",".MP3",".OGG",".FLAC",".APE",".WV",".M4A",".AAC",".MPC",".WMA",".SHN",".RM",".DTS",".AIF",".AIFF",".AIFC",".CUE",""};
 	gchar	*TabFileWav[]    = {".WAV",""};
@@ -384,7 +389,16 @@ void fileanalyze_verif_validity_files (void)
 					g_free (VarListFiles);
 					VarListFiles = List->data = NULL;
 				}
-				g_print ("TypeFileIs = %d\n",TypeFileIs);
+				// PROGRAM checkmp3 (mp3check) NOT FOUND
+				else if (FILE_IS_MP3 == TypeFileIs && FALSE == PrgInit.bool_checkmp3) {
+					
+					VarAnalyze.BoolNoFindCheckMp3 = TRUE;
+					
+					g_free (VarListFiles->Name);
+					VarListFiles->Name = NULL;
+					g_free (VarListFiles);
+					VarListFiles = List->data = NULL;
+				}
 			}
 			else if (_PATH_LOAD_FILE_WAV_ == VarAnalyze.TypeFileselection) {
 				if (-1 == ((TypeFileIs = fileanalyze_is_valid (VarListFiles->Name,_PATH_LOAD_FILE_WAV_)))) {
@@ -403,6 +417,16 @@ void fileanalyze_verif_validity_files (void)
 					g_free (VarListFiles);
 					VarListFiles = List->data = NULL;
 				}
+				// PROGRAM checkmp3 (mp3check) NOT FOUND
+				else if (FILE_IS_MP3 == TypeFileIs && FALSE == PrgInit.bool_checkmp3) {
+					
+					VarAnalyze.BoolNoFindCheckMp3 = TRUE;
+					
+					g_free (VarListFiles->Name);
+					VarListFiles->Name = NULL;
+					g_free (VarListFiles);
+					VarListFiles = List->data = NULL;
+				}
 			}
 			else if (_PATH_LOAD_FILE_TAGS_ == VarAnalyze.TypeFileselection) {
 				if (-1 == ((TypeFileIs = fileanalyze_is_valid (VarListFiles->Name,_PATH_LOAD_FILE_TAGS_)))) {
@@ -412,6 +436,16 @@ void fileanalyze_verif_validity_files (void)
 					g_free (VarListFiles);
 					VarListFiles = List->data = NULL;
 				}
+				// PROGRAM checkmp3 (mp3check) NOT FOUND
+				else if (FILE_IS_MP3 == TypeFileIs && FALSE == PrgInit.bool_checkmp3) {
+					
+					VarAnalyze.BoolNoFindCheckMp3 = TRUE;
+					
+					g_free (VarListFiles->Name);
+					VarListFiles->Name = NULL;
+					g_free (VarListFiles);
+					VarListFiles = List->data = NULL;
+				}
 			}
 			// STOCKE LE TYPE DE FICHIER
 			if (NULL != VarListFiles) {
@@ -487,7 +521,6 @@ void fileanalyze_set_in_list (void)
 			}
 			
 			if (VarListFiles->TypeFileIs == FILE_IS_FLAC)         detail->info = tagsflac_get_info (detail);
-			// else if (VarListFiles->TypeFileIs == FILE_IS_WAV)     detail->info = tagswav_get_info (detail);
 			else if (VarListFiles->TypeFileIs == FILE_IS_WAV)     detail->info = tagswav_get_info (detail->namefile);
 			else if (VarListFiles->TypeFileIs == FILE_IS_MP3)     detail->info = tagsmp3_get_info (detail);
 			else if (VarListFiles->TypeFileIs == FILE_IS_OGG)     detail->info = tagsogg_get_info (detail);
@@ -544,6 +577,7 @@ static void fileanalyze_thread (void *arg)
 	
 	// ALIMENTATION DE LA LISTE
 	fileanalyze_set_in_list ();
+	
 	// REMOVE COPIE DU GLIST
 	VarAnalyze.ListFiles = libutils_remove_glist (VarAnalyze.ListFiles);
 
@@ -573,6 +607,13 @@ static gint fileanalyze_timeout (gpointer data)
 		FileWav_affiche_glist ();
 		FileMp3Ogg_affiche_glist ();
 		FileTags_affiche_glist ();
+		
+		if (TRUE == VarAnalyze.BoolNoFindCheckMp3) {
+			wininfo_create (
+				_("Package checkmp3 (mp3check) NOT FOUND !"),
+				_("Veuillez installer checkmp3 ou mp3check pour\nla prise en compte des fichiers mp3"),
+			  	"");
+		}
 	}
 	return (TRUE);
 }
@@ -608,6 +649,7 @@ void fileanalyze_add_file_to_treeview (TYPE_FILESELECTION p_TypeFileselection, G
 	// CALL THREAD
 	VarAnalyze.BoolInThread = TRUE;
 	VarAnalyze.BoolSetPercent = FALSE;
+	VarAnalyze.BoolNoFindCheckMp3 = FALSE;
 	
 	pthread_create (&nmr_tid_1, NULL ,(void *)fileanalyze_thread, (void *)NULL);
 	VarAnalyze.HandlerTimeoutDo = gtk_timeout_add (100, fileanalyze_timeout, 0);
