@@ -3,7 +3,7 @@
  * project   : xcfa
  * with      : Gtk-2
  *
- * copyright : (C) 2003 - 2010 by Claude Bulin
+ * copyright : (C) 2003 - 2011 by Claude Bulin
  *
  * xcfa - GTK+ implementation of the GNU shell command
  * GNU General Public License
@@ -518,16 +518,28 @@ GString *GetInfo_checkmp3 (gchar *file)
 	gchar    buf [ GET_MAX_CARS + 10 ];
 	gint     size = 0;
 	GString *gstr = NULL;
-
+	
+	if (FALSE == PrgInit.bool_checkmp3) {
+		PRINT_FUNC_LF();
+		g_print ("\tPrgInit.bool_checkmp3 = %s\n", PrgInit.bool_checkmp3 ? "TRUE" : "FALSE");
+		g_print ("\tIL FAUT INSTALLER checkmp3 OU mp3check SUIVANT VOTRE DISTRIBUTION !\n\n");
+		return (NULL);
+	}
 	gstr = g_string_new (NULL);
 
 	// args[pos++] = PrgInit.name_checkmp3;
 	args[pos++] = prginit_get_name (NMR_checkmp3);
 	args[pos++] = "-a";
 	args[pos++] = "-v";
-	args[pos++] = "-i";
+	
+	// TODO: @Tetsumaki
+	// http://forum.ubuntu-fr.org/viewtopic.php?pid=3889239#p3889239
+	// OPTION -i n'existe pas sous ARCHLINUX !!!
+	// args[pos++] = "-i";
+
 	args[pos++] = file;
 	args[pos++] = NULL;
+
 	/*
 	g_print ("!-----------------------------------!\n");
 	g_print ("!           C H E C K M P 3         !\n");
@@ -536,6 +548,7 @@ GString *GetInfo_checkmp3 (gchar *file)
 		g_print ("args [ %02d ] = '%s'\n", pos, args [ pos ]);
 	g_print ("\n");
 	*/
+
 	fd = GetInfo_exec_with_output (args, &VarGet.code_fork, STDOUT_FILENO);
 	do {
 		pos = -1;
