@@ -3,7 +3,7 @@
  * project   : xcfa
  * with      : Gtk-2
  *
- * copyright : (C) 2003 - 2010 by Claude Bulin
+ * copyright : (C) 2003 - 2011 by Claude Bulin
  *
  * xcfa - GTK+ implementation of the GNU shell command
  * GNU General Public License
@@ -47,6 +47,8 @@
 #include <stdio.h>
 #include <stdlib.h>
 #include <getopt.h>
+#include <unistd.h>
+#include <sys/types.h>
 
 #ifdef ENABLE_STATIC_LIBRARY
 	#include "../lib/lib.h"
@@ -70,6 +72,7 @@
 #include "process.h"
 #include "split.h"
 #include "alsa_play.h"
+#include "win_info.h"
 #include "global.h"
 
 
@@ -169,7 +172,12 @@ GtkWidget *create_pixmap (GtkWidget *widget, const gchar *filename)
 // 
 void main_puts_statusbar_global (gchar *mess_label_status)
 {
-	if (AdrLabelStatusbarGlobal) {
+	static	gboolean Bool_puts_statusbar_global = FALSE;
+	
+	if (NULL != AdrLabelStatusbarGlobal && FALSE == Bool_puts_statusbar_global) {
+		
+		// NO ACESS IN PROC
+		Bool_puts_statusbar_global = TRUE;
 		
 		gchar *New_Str = NULL;
 		gchar *NewName = g_strnfill (strlen(mess_label_status) * 4, '\0');
@@ -193,7 +201,11 @@ void main_puts_statusbar_global (gchar *mess_label_status)
 		New_Str = g_strdup_printf ("<span color=\"black\"><b>%s</b></span>", NewName);
 		
 		gtk_label_set_justify (GTK_LABEL (AdrLabelStatusbarGlobal), GTK_JUSTIFY_CENTER);
-		while (gtk_events_pending()) gtk_main_iteration(); 
+		
+		// TODO : @Tetsumaki  http://forum.ubuntu-fr.org/viewtopic.php?pid=3889380#p3889380
+		// TODO : bug avec: while ...
+		// while (gtk_events_pending()) gtk_main_iteration(); 
+		
 		gtk_label_set_use_markup (GTK_LABEL (AdrLabelStatusbarGlobal), TRUE);
 		gtk_label_set_markup (GTK_LABEL (AdrLabelStatusbarGlobal), New_Str);
 
@@ -201,6 +213,9 @@ void main_puts_statusbar_global (gchar *mess_label_status)
 		New_Str = NULL;
 		g_free (NewName);
 		NewName = NULL;
+		
+		// ACESS IN PROC IS OK
+		Bool_puts_statusbar_global = FALSE;
 	}
 }
 // 
@@ -818,10 +833,18 @@ gint main (gint argc, gchar *argv[], gchar **envp)
 	
 	// INHIBER LE JOURNAL DE LOGS
 	gtk_widget_set_sensitive (GTK_WIDGET (GLADE_GET_OBJECT("frame_journal")), FALSE);
-	
+		
 	// SI CHARGEMENT DE FICHIERS DEPUIS LE BUREAU AVEC LE MENU CONTEXTUEL
 	process_goto_timeout ();
 	
+	// ADMINISTRATOR MOD ?
+	if (0 == getuid()) {
+		wininfo_create (
+			_("MODE ADMINISTRATEUR"),
+			_("Vous ne devriez pas utiliser XCFA sous ROOT !"),
+			"");
+	}
+	
 	gtk_main ();
 	gdk_threads_leave ();
 	
