@@ -3,7 +3,7 @@
  * project   : xcfa
  * with      : Gtk-2
  *
- * copyright : (C) 2003 - 2010 by Claude Bulin
+ * copyright : (C) 2003 - 2011 by Claude Bulin
  *
  * xcfa - GTK+ implementation of the GNU shell command
  * GNU General Public License
@@ -426,18 +426,6 @@ NULL,								// NAME TREE-VIEW
 NULL,								// PIXBUF TREE-VIEW
 NULL},								// DESCRIPTION
 
-{"txt2html",							// PACKAGEDEBIAN_64
-"txt2html",							// PACKAGEDEBIAN_32
-"txt2html",							// NAME1
-"",								// NAME2
-"",								// NAME3
-&PrgInit.bool_txt2html,						// FOUND
-"",								// DEPOTDEBIAN_64
-"",								// DEPOTDEBIAN_32
-NULL,								// NAME TREE-VIEW
-NULL,								// PIXBUF TREE-VIEW
-NULL},								// DESCRIPTION
-
 {"vorbis-tools",						// PACKAGEDEBIAN_64
 "vorbis-tools",							// PACKAGEDEBIAN_32
 "oggenc",							// NAME1
@@ -484,18 +472,6 @@ NULL},								// DESCRIPTION
 "",								// DEPOTDEBIAN_32
 NULL,								// NAME TREE-VIEW
 NULL,								// PIXBUF TREE-VIEW
-NULL},								// DESCRIPTION
-
-{"w64codecs",							// PACKAGEDEBIAN_64
-"w32codecs",							// PACKAGEDEBIAN_32
-"w64codecs",							// NAME1
-"w32codecs",							// NAME2
-"",								// NAME3
-&PrgInit.bool_w32codecs,					// FOUND
-"",								// DEPOTDEBIAN_64
-"",								// DEPOTDEBIAN_32
-NULL,								// NAME TREE-VIEW
-NULL,								// PIXBUF TREE-VIEW
 NULL}								// DESCRIPTION
 
 };
@@ -534,6 +510,12 @@ void on_label_type_package_realize (GtkWidget *widget, gpointer user_data)
 		}
 		var_options.Type_Package = _RPM_;
 	}
+	else if (libutils_find_file ("yaourt") == TRUE || libutils_find_file ("pacman") == TRUE) {
+		if (widget != NULL) {
+			New_Str = g_strdup_printf (_(" <b>... les paquets: pkg.tar.xz</b> "));
+		}
+		var_options.Type_Package = _ARCHLINUX_;
+	}
 	else {
 		if (widget != NULL) {
 			New_Str = g_strdup_printf (_(" <b>... les paquets: ?</b> "));
@@ -662,14 +644,14 @@ void prginit_scan (void)
 		}
 				
 		// CAS: NMR_wXXcodecs
-		
-		if (index == NMR_wXXcodecs) {
-			if (HostConf.BoolCpuIs64Bits == TRUE) {
-				TableauPrgExtern [ index ] . PtrName = TableauPrgExtern [ index ] .Name1;
-			} else {
-				TableauPrgExtern [ index ] . PtrName = TableauPrgExtern [ index ] .Name2;
-			}
-		}
+		// 
+		// if (index == NMR_wXXcodecs) {
+		// 	if (HostConf.BoolCpuIs64Bits == TRUE) {
+		// 		TableauPrgExtern [ index ] . PtrName = TableauPrgExtern [ index ] .Name1;
+		// 	} else {
+		// 		TableauPrgExtern [ index ] . PtrName = TableauPrgExtern [ index ] .Name2;
+		// 	}
+		// }
 		
 		// FIXER LE PIXBUF SI PAS EN SELECTION
 		
@@ -701,7 +683,6 @@ gboolean prginit_get_etat (void)
 		PrgInit.bool_faad &
 		PrgInit.bool_faac &
 		PrgInit.bool_mplayer &
-		PrgInit.bool_w32codecs &
 		PrgInit.bool_shorten &
 		PrgInit.bool_convert &
 		PrgInit.bool_wavpack &
@@ -807,8 +788,10 @@ void prginit_remove_comment (void)
 	gint	index;
 	
 	for (index = 0; index < NMR_MAX_TABLEAU; index ++) {
-		g_free (TableauPrgExtern[ index ].Description);
-		TableauPrgExtern[ index ].Description = NULL;
+		if (NULL != TableauPrgExtern[ index ].Description) {
+			g_free (TableauPrgExtern[ index ].Description);
+			TableauPrgExtern[ index ].Description = NULL;
+		}
 	}
 }
 // 
@@ -840,12 +823,10 @@ void prginit_init_comment (void)
 	TableauPrgExtern[ NMR_shorten ].Description 			= g_strdup (_(" [ shorten ] Forte compression au format wave"));
 	TableauPrgExtern[ NMR_shntool ].Description			= g_strdup (_(" [ shntool ] Decoupage de fichiers sans decodage"));
 	TableauPrgExtern[ NMR_sox ].Description 			= g_strdup (_(" [ sox ] Transformation universelle de fichiers son"));
-	TableauPrgExtern[ NMR_txt2html ].Description 			= g_strdup (_(" [ txt2html ] Convertir des fichiers texte au format HTML"));
 	TableauPrgExtern[ NMR_vorbis_tools_oggenc ].Description		= g_strdup (_(" [ Vorbis-tools ] Conversion wav : ogg"));
 	TableauPrgExtern[ NMR_vorbisgain ].Description 			= g_strdup (_(" [ vorbisgain ] Normaliseur de fichier ogg"));
 	TableauPrgExtern[ NMR_wavsplit ].Description 			= g_strdup (_(" [ wavsplit ] Decoupage de fichiers sans decodage"));
 	TableauPrgExtern[ NMR_wavpack ].Description 			= g_strdup (_(" [ wavpack ] WAVPACK  Hybrid Lossless Audio Compressor"));
-	TableauPrgExtern[ NMR_wXXcodecs	].Description 			= g_strdup (_(" [ wXXcodecs ] Codecs video non supportes par mplayer / <b><i>PAS indispensable</i></b>"));
 }
 // INITIALISATION DU SCROLLWINDOW
 // 
