@@ -3,7 +3,7 @@
  * project   : xcfa
  * with      : Gtk-2
  *
- * copyright : (C) 2003 - 2010 by Claude Bulin
+ * copyright : (C) 2003 - 2011 by Claude Bulin
  *
  * xcfa - GTK+ implementation of the GNU shell command
  * GNU General Public License
@@ -82,12 +82,10 @@ typedef enum {
 	NMR_shorten,
 	NMR_shntool,
 	NMR_sox,
-	NMR_txt2html,
 	NMR_vorbis_tools_oggenc,
 	NMR_vorbisgain,
 	NMR_wavsplit,
 	NMR_wavpack,
-	NMR_wXXcodecs,
 	
 	NMR_MAX_TABLEAU
 } TYPE_PROGINIT;
@@ -130,7 +128,6 @@ typedef struct {
 	gboolean	bool_faad;
 	gboolean	bool_faac;
 	gboolean	bool_mplayer;
-	gboolean	bool_w32codecs;
 	gboolean	bool_shorten;
 	gboolean	bool_convert;
 	gboolean	bool_lsdvd;
@@ -143,7 +140,6 @@ typedef struct {
 	gboolean	bool_shntool;
 	gboolean	bool_cuetools;
 	gboolean	bool_aacplusenc;
-	gboolean	bool_txt2html;
 
 } PRGINIT;
 
