@@ -3,7 +3,7 @@
  * project   : xcfa
  * with      : Gtk-2
  *
- * copyright : (C) 2003 - 2010 by Claude Bulin
+ * copyright : (C) 2003 - 2011 by Claude Bulin
  *
  * xcfa - GTK+ implementation of the GNU shell command
  * GNU General Public License
@@ -207,6 +207,7 @@ void split_set_flag_buttons (void)
 	gtk_widget_grab_focus (VarSplit.AdrWidgetSpectre);
 	
 	split_set_time ();
+	split_set_name_file ();
 }
 // 
 // 
@@ -831,7 +832,8 @@ gboolean on_eventbox_splitspectre_expose_event (GtkWidget *drawing, GdkEventExpo
 }
 // 
 // 
-void split_set_name_file (void)
+/*
+void OLD_split_set_name_file (void)
 {
 	gchar	*Ptr = NULL;
 	
@@ -847,8 +849,6 @@ void split_set_name_file (void)
 			Str = g_strdup_printf ("<b>%s</b>", Ptr);
 
 		}
-		// gtk_label_set_use_markup (GTK_LABEL(GLADE_GET_OBJECT("label_filename_split")), TRUE);
-		// gtk_label_set_markup (GTK_LABEL(GLADE_GET_OBJECT("label_filename_split")), Str);
 		main_puts_statusbar_global (Str);
 		g_free (Str);
 		Str = NULL;
@@ -857,6 +857,41 @@ void split_set_name_file (void)
 		main_puts_statusbar_global (_("<i>Pret pour l'import d'un fichier CUE, WAV, FLAC, OGG, MP3, APE</i>"));
 	}
 }
+*/
+void split_set_name_file (void)
+{
+	gchar	*Ptr = NULL;
+	
+	if (NULL != VarSplit.PathNameFileReal && NULL != (Ptr = strrchr (VarSplit.PathNameFileReal, '/'))) {
+		gchar	*Str = NULL;
+		
+		Ptr ++;		
+		if (NULL != VarSplit.Tags) {
+			Str = g_strdup_printf ("%s      %s\n%s Hertz\n%s voies\n%s bits ",
+						Ptr, VarSplit.Tags->time, VarSplit.Tags->hertz, VarSplit.Tags->voie, VarSplit.Tags->bits);
+		}
+		else {
+			Str = g_strdup_printf ("<b>%s</b>", Ptr);
+
+		}
+		gtk_label_set_use_markup (GTK_LABEL(GLADE_GET_OBJECT("label_temps_actuel_curseur_split")), TRUE);
+		gtk_label_set_markup (GTK_LABEL(GLADE_GET_OBJECT("label_temps_actuel_curseur_split")), Str);
+		
+		g_free (Str);	Str = NULL;
+		
+		if (VarSplit.NbrSelecteurs > 1) {
+			Str = g_strdup_printf (_("Menu: Click droit   /   Ajout plage: Click bouton centre"));
+		}
+		else {
+			Str = g_strdup_printf (_("Ajout plage: Click bouton centre"));
+		}
+		main_puts_statusbar_global (Str);
+		g_free (Str);	Str = NULL;
+	}
+	else {
+		main_puts_statusbar_global (_("<i>Pret pour l'import d'un fichier CUE, WAV, FLAC, OGG, MP3, APE</i>"));
+	}
+}
 //
 // 
 static void VarSplit_thread (void *arg)
