@@ -3,7 +3,7 @@
  * project   : xcfa
  * with      : Gtk-2
  *
- * copyright : (C) 2003 - 2010 by Claude Bulin
+ * copyright : (C) 2003 - 2011 by Claude Bulin
  *
  * xcfa - GTK+ implementation of the GNU shell command
  * GNU General Public License
@@ -99,6 +99,9 @@ TRANS trans[] = {
 { _(" Creation d'un fichier unique ") },
 { _("<b>Gestion des tags, titres et fichiers cue</b>") },
 { _("<b> Normaliser </b>") },
+{ _("definit le serveur a contacter pour les recherches titre") },
+{ _("definit le nombre de port a utiliser pour les recherches titre") },
+{ _("Parametres par defaut") },
 { _("<b> Serveurs </b>") },
 { _("Extraire") },
 { _(" CD ") },
@@ -325,7 +328,7 @@ TRANS trans[] = {
 { _("<b> Installation </b>") },
 { _("<b> Votre systeme utilise ... </b>") },
 { _("\n<b><i>Pour installer les programmes externes requis,\nveuillez utiliser l'installateur de votre distribution Gnu/Linux.</i></b>\n") },
-{ _("xcfa_install_all  ecrit en Perl vous sera utile en ligne de commande pour une installation complementaire.") },
+{ _("Le programme XCFA_INSTALL_ALL ecrit en Perl vous sera utile en ligne de commande pour une installation des programmes complementaire.") },
 { _("<b> Informations </b>") },
 { _(" Application externes ") },
 { _("<i>parametres:</i>") },
