@@ -3,7 +3,7 @@
  * project   : xcfa
  * with      : Gtk-2
  *
- * copyright : (C) 2003 - 2010 by Claude Bulin
+ * copyright : (C) 2003 - 2011 by Claude Bulin
  *
  * xcfa - GTK+ implementation of the GNU shell command
  * GNU General Public License
@@ -42,6 +42,8 @@
 #endif
 
 #include <gtk/gtk.h>
+#include <glib.h>
+#include <glib/gprintf.h>
 #include <sys/types.h>
 #include <unistd.h>
 #include <string.h>
@@ -92,8 +94,7 @@ void web_call_navigator (void)
 {
 	pid_t  pid;
 
-	pid = fork ();
-	if (pid == 0) {
+	if ((pid = fork ()) == 0) {
 		/*
 		kfmclient newTab http://www.xcfa.tuxfamily.org &
 		*/
@@ -173,6 +174,7 @@ void web_goto_url (gchar *str_web)
 	VarWeb.NameNavi   = g_strdup (str_web);
 	
 	pthread_create (&nmr_tid, NULL ,(void *)web_thread, (void *)NULL);
+	sleep(5);
 }
 // 
 // 
@@ -193,8 +195,13 @@ void web_make_file (gchar *StrMakeManFile)
 // 
 void web_goto_manpage (gchar *NameManPage)
 {
-	pthread_t	 nmr_tid;
+	pthread_t	nmr_tid;
 	gchar		*LineCommand = NULL;
+	gchar		*PathNameMan = NULL;
+	gchar		*PathNameHtml = NULL;
+	FILE		*fp_man = NULL;
+	FILE		*fp_html = NULL;
+	gchar		buf [ 4 ];
  	
 	// PRINT_FUNC_LF();
 
@@ -217,22 +224,14 @@ void web_goto_manpage (gchar *NameManPage)
 
 	if (libutils_find_file (NameManPage) == FALSE) {
 		g_print("The application is missing, you must install [ %s ]\n", NameManPage);
-		return;
-	}
-	
-	if (libutils_find_file ("txt2html") == FALSE) {
-		// g_print("The application is missing, you must install [ txt2html ]\n");
 		wininfo_create (
-			_("txt2html absent"),
-			  "\n",
-			_("   txt2html est absent de votre configuration."),
-			  "\n\n",
-			_("   Veuillez l'installer."),
+			_("L'application est absente."),
+			_("Veuillez installer : "), "<b>", NameManPage, "</b>",
 			  "\n",
 			  "");
 		return;
 	}
-	
+		
 	// INIT DOSSIER TEMPORAIRE
 	if (NULL == VarWeb.TemporaryRep)  {
 		VarWeb.TemporaryRep  = libutils_create_temporary_rep (Config.PathnameTMP, PATH_MANPAGE);
@@ -245,11 +244,51 @@ void web_goto_manpage (gchar *NameManPage)
 	
 	// IF VarWeb.NameNavi NOT EXIST
 	if (FALSE == libutils_test_file_exist (VarWeb.NameNavi)) {	
-		LineCommand = g_strdup_printf ("man %s | txt2html > %s/%s.html", NameManPage, VarWeb.TemporaryRep, NameManPage);
+				
+		LineCommand = g_strdup_printf ("man %s > %s/%s.txt", NameManPage, VarWeb.TemporaryRep, NameManPage);
+		g_print("LineCommand = %s\n", LineCommand);
 		web_make_file (LineCommand);
-		g_free (LineCommand);
-		LineCommand = NULL;
+		g_free (LineCommand);	LineCommand = NULL;
 		sleep(20);
+		
+		PathNameMan  = g_strdup_printf ("%s/%s.txt", VarWeb.TemporaryRep, NameManPage);
+		g_print("PathNameMan = %s\n", PathNameMan);
+		PathNameHtml = g_strdup_printf ("%s/%s.html", VarWeb.TemporaryRep, NameManPage);
+		fp_man  = fopen (PathNameMan, "r");
+		fp_html = fopen (PathNameHtml, "w");
+		
+		g_fprintf (fp_html, "<html>\n");
+		g_fprintf (fp_html, "<head>\n");
+		g_fprintf (fp_html, "  <title>%s</title>\n", NameManPage);
+		g_fprintf (fp_html, "</head>\n");
+		g_fprintf (fp_html, "<body bgcolor=\"#ffffff\" text=\"#000000\">\n");
+		g_fprintf (fp_html, "<pre>\n");
+		
+		while (fread (&buf, 1, 1, fp_man)) {
+			if ((gint)*buf >= 0) {
+				if (*buf == '<') {
+					g_fprintf (fp_html, "&lt;");
+					// g_print("&lt;");
+				}
+				else if (*buf == '>') {
+					g_fprintf (fp_html, "&gt;");
+					// g_print("&gt;");
+				}
+				else {
+					buf [ 1 ] = '\0';
+					g_fprintf (fp_html, "%s", buf);
+					// g_print("%s", buf);
+				}
+			}
+		}
+		fclose (fp_man);
+		g_fprintf (fp_html, "</pre>\n");
+		g_fprintf (fp_html, "</body>\n");
+		g_fprintf (fp_html, "</html>\n\n");
+		fclose (fp_html);
+		
+		g_free (PathNameMan);	PathNameMan = NULL;
+		g_free (PathNameHtml);	PathNameHtml = NULL;
 	}
 		
 	pthread_create (&nmr_tid, NULL ,(void *)web_thread, (void *)NULL);
@@ -316,9 +355,12 @@ void on_button_WebInformations_clicked (GtkButton *button, gpointer user_data)
 }
 // 
 // 
-void on_linkbutton_xcfa_install_all_clicked (GtkLinkButton *link_button, gpointer user_data)
+void on_button_see_xcfa_install_clicked (GtkButton *button, gpointer user_data)
 {
-	g_print("%s\n", gtk_link_button_get_uri (link_button));
-	web_goto_url ((gchar *)gtk_link_button_get_uri (link_button));
+	web_goto_url ("http://www.xcfa.tuxfamily.org/index.php?static2/xcfa");
+	sleep(5);
+	web_goto_url ("http://download.tuxfamily.org/xcfaudio/PlusPlus/");
 }
 
+
+
